from aparatdl.scraper import Scraper
import requests
from aparatdl.exceptions import DownloadError
import speedtest


class Main:
    def __init__(self, url, quality):
        self.url = url
        self.quality = str(quality) if quality[-1] == 'p' else quality +'p'
        self.scraper = Scraper(self.url,self.quality)

    def speed_download(self):
        st = int(speedtest.Speedtest().download())
        return st

    def download(self):
        video_url = self.scraper.get_link()
        video_name = video_url.split('/')[-1][:41] + self.quality
        with open(video_name,'wb') as f:
            print('start downloading...')
            result = requests.get(video_url,stream=True)
            total_video_size = int(result.headers.get('content-length'))

            if total_video_size is None:
                raise DownloadError('An unpredictable problem has occurred. Please try again')
            else:
                download = 0
                st = self.speed_download()
                Estimation_time_dl = round(total_video_size*8 / st,2)
                print(f'speed download {round(st/1000000,2)} Mb/s')
                print(f'download video per {Estimation_time_dl} second')
                for data in result.iter_content(chunk_size=4096):
                    f.write(data)
                    download +=len(data)
                    done = int(50 * download / total_video_size)
                    print("\r[%s %s]" % ('=' * done, ' ' * (50 - done)), end='')
        print('\nvideo downloaded...')

m = Main('https://www.aparat.com/v/7CUzr/','144')
m.download()
# print(m.speed_download())



import requests
from bs4 import BeautifulSoup
from aparatdl.exceptions import QualityError


class Scraper:
    def __init__(self,url,quality=None):
        self.url = url
        self.quality = quality

    def get_data(self):
        get_data = requests.get(self.url)
        content = BeautifulSoup(get_data.text, 'html.parser')
        get_tag_links = content.findAll('li', {'class': 'menu-item-link link'})
        return get_tag_links

    def get_all_links(self):
        get_tag_links = self.get_data()
        links = [li.a['href'] for li in get_tag_links]
        return links

    def get_all_quality(self):
        get_tag_links = self.get_data()
        aria_label = [[i for i in li.a['aria-label'].split()] for li in get_tag_links]
        qualities = [i[-1] for i in aria_label]
        return qualities

    def get_link(self):
        qualities = self.get_all_quality()
        links = self.get_all_links()
        if self.quality not in qualities:
            raise QualityError(f'this is a quality ({self.quality}) is not available!!!\n'
                               f'the available qualities are {qualities}')
        else:
            index = None
            for i in range(len(qualities)):
                if qualities[i] == self.quality:
                    index = i
        return links[index]
